kedro.extras.datasets.pandas.ExcelDataSet — Kedro 0.17.6 documentation

# kedro.extras.datasets.pandas.ExcelDataSet

class `kedro.extras.datasets.pandas.` `ExcelDataSet`(filepath, engine='xlsxwriter', load_args=None, save_args=None, version=None, credentials=None, fs_args=None)

  `ExcelDataSet` loads/saves data from/to a Excel file using an underlying filesystem (e.g.: local, S3, GCS). It uses pandas to handle the Excel file.

  Example adding a catalog entry with YAML API:

      rockets:
        type: pandas.ExcelDataSet
        filepath: gcs://your_bucket/rockets.xlsx
        fs_args:
          project: my-project
        credentials: my_gcp_credentials
        save_args:
          sheet_name: Sheet1
        load_args:
          sheet_name: Sheet1

      shuttles:
        type: pandas.ExcelDataSet
        filepath: data/01_raw/shuttles.xlsx

  Example using Python API:

      from kedro.extras.datasets.pandas import ExcelDataSet
      import pandas as pd

      data = pd.DataFrame({'col1': [1, 2], 'col2': [4, 5],
                           'col3': [5, 6]})

      # data_set = ExcelDataSet(filepath="gcs://bucket/test.xlsx")
      data_set = ExcelDataSet(filepath="test.xlsx")
      data_set.save(data)
      reloaded = data_set.load()
      assert data.equals(reloaded)

  Attributes

  `DEFAULT_LOAD_ARGS` |
  `DEFAULT_SAVE_ARGS` |

  Methods

  `exists`() | Checks whether a data set’s output already exists by calling the provided _exists() method.
  `from_config`(name, config[, load_version, …]) | Create a data set instance using the configuration provided.
  `load`() | Loads data by delegation to the provided load method.
  `release`() | Release any cached data.
  `resolve_load_version`() | Compute the version the dataset should be loaded with.
  `resolve_save_version`() | Compute the version the dataset should be saved with.
  `save`(data) | Saves data by delegation to the provided save method.

  `DEFAULT_LOAD_ARGS` = {'engine': 'xlrd'}
  `DEFAULT_SAVE_ARGS` = {'index': False}
  `__init__`(filepath, engine='xlsxwriter', load_args=None, save_args=None, version=None, credentials=None, fs_args=None)

    Creates a new instance of `ExcelDataSet` pointing to a concrete Excel file on a specific filesystem.

    Parameters

      - filepath (`str`) – Filepath in POSIX format to a Excel file prefixed with a protocol like s3://. If prefix is not provided, file protocol (local filesystem) will be used. The prefix should be any protocol supported by `fsspec`. Note: http(s) doesn’t support versioning.

      - engine (`str`) – The engine used to write to excel files. The default engine is ‘xlsxwriter’.

      - load_args (`Optional`[`Dict`[`str`, `Any`]]) – Pandas options for loading Excel files. Here you can find all available arguments: https://pandas.pydata.org/pandas-docs/stable/generated/pandas.read_excel.html All defaults are preserved, but “engine”, which is set to “xlrd”. Supports multi-sheet Excel files (include sheet_name = None in load_args).

      - save_args (`Optional`[`Dict`[`str`, `Any`]]) – Pandas options for saving Excel files. Here you can find all available arguments: https://pandas.pydata.org/pandas-docs/stable/generated/pandas.DataFrame.to_excel.html All defaults are preserved, but “index”, which is set to False. If you would like to specify options for the ExcelWriter, you can include them under the “writer” key. Here you can find all available arguments: https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.ExcelWriter.html

      - version (`Optional`[`Version`]) – If specified, should be an instance of `kedro.io.core.Version`. If its `load` attribute is None, the latest version will be loaded. If its `save` attribute is None, save version will be autogenerated.

      - credentials (`Optional`[`Dict`[`str`, `Any`]]) – Credentials required to get access to the underlying filesystem. E.g. for `GCSFileSystem` it should look like {“token”: None}.

      - fs_args (`Optional`[`Dict`[`str`, `Any`]]) – Extra arguments to pass into underlying filesystem class constructor (e.g. {“project”: “my-project”} for `GCSFileSystem`), as well as to pass to the filesystem’s open method through nested keys open_args_load and open_args_save. Here you can find all available arguments for open: https://filesystem-spec.readthedocs.io/en/latest/api.html#fsspec.spec.AbstractFileSystem.open All defaults are preserved, except mode, which is set to wb when saving.

  `exists`()

    Checks whether a data set’s output already exists by calling the provided _exists() method.

    Return type

      `bool`

    Returns

      Flag indicating whether the output already exists.

    Raises

      DataSetError – when underlying exists method raises error.

  classmethod `from_config`(name, config, load_version=None, save_version=None)

    Create a data set instance using the configuration provided.

    Parameters

      - name (`str`) – Data set name.

      - config (`Dict`[`str`, `Any`]) – Data set config dictionary.

      - load_version (`Optional`[`str`]) – Version string to be used for `load` operation if the data set is versioned. Has no effect on the data set if versioning was not enabled.

      - save_version (`Optional`[`str`]) – Version string to be used for `save` operation if the data set is versioned. Has no effect on the data set if versioning was not enabled.

    Return type

      `AbstractDataSet`

    Returns

      An instance of an `AbstractDataSet` subclass.

    Raises

      DataSetError – When the function fails to create the data set from its config.

  `load`()

    Loads data by delegation to the provided load method.

    Return type

      `Any`

    Returns

      Data returned by the provided load method.

    Raises

      DataSetError – When underlying load method raises error.

  `release`()

    Release any cached data.

    Raises

      DataSetError – when underlying release method raises error.

    Return type

      `None`

  `resolve_load_version`()

    Compute the version the dataset should be loaded with.

    Return type

      `Optional`[`str`]

  `resolve_save_version`()

    Compute the version the dataset should be saved with.

    Return type

      `Optional`[`str`]

  `save`(data)

    Saves data by delegation to the provided save method.

    Parameters

      data (`Any`) – the value to be saved by provided save method.

    Raises

      - DataSetError – when underlying save method raises error.

      - FileNotFoundError – when save method got file instead of dir, on Windows.

      - NotADirectoryError – when save method got file instead of dir, on Unix.

    Return type

      `None`